@@ -1,14 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  begin:     Wed Feb 6 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #ifndef MODEBUTTON_H
@@ -30,11 +23,14 @@ class ModeButton : public QToolButton
     Q_SIGNALS:
         void modeClicked(int id,bool on);
 
-    public Q_SLOTS:
+    private Q_SLOTS:
         void wasClicked();
 
-    protected:
+    private:
         int id;
         bool on;
+
+        Q_DISABLE_COPY(ModeButton)
 };
+
 #endif
