@@ -1,13 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  copyright: (C) 2004 by Peter Simonsson
-  email:     psn@linux.se
+    SPDX-FileCopyrightText: 2004 Peter Simonsson <psn@linux.se>
 */
 
 #ifndef KONVERSATIONCHANNELOPTIONSDIALOG_H
@@ -17,10 +11,10 @@
 #include "channel.h"
 
 #include <QStringList>
-#include <QAbstractListModel>
 
 #include <QDialog>
 
+class QTimer;
 
 namespace Konversation
 {
@@ -32,8 +26,8 @@ namespace Konversation
             explicit ChannelOptionsDialog(Channel *channel);
             ~ChannelOptionsDialog() override;
 
-            QString topic();
-            QStringList modes();
+            QString topic() const;
+            QStringList modes() const;
 
             /**
              * Return the whatsThis string for a mode-change button.
@@ -59,20 +53,27 @@ namespace Konversation
 
             void changeOptions();
 
-        protected Q_SLOTS:
-            void topicHistoryItemClicked(const QItemSelection& selection);
-            void topicBeingEdited(bool edited);
-
         protected:
             void showEvent(QShowEvent* event) override;
             void hideEvent(QHideEvent* event) override;
 
+        private Q_SLOTS:
+            void topicHistoryItemClicked(const QItemSelection& selection);
+            void topicBeingEdited(bool edited);
+
+            void startHistorySearchTimer(const QString &filter);
+            void updateHistoryFilter();
+
+        private:
             bool m_editingTopic;
             bool m_isAnyTypeOfOp;
 
-        private:
             Ui::ChannelOptionsUI m_ui;
             Channel *m_channel;
+
+            QTimer* m_historySearchTimer;
+
+            Q_DISABLE_COPY(ChannelOptionsDialog)
     };
 
     class BanListViewItem : public QTreeWidgetItem
@@ -80,11 +81,14 @@ namespace Konversation
         public:
             explicit BanListViewItem( QTreeWidget *parent );
             BanListViewItem(QTreeWidget *parent, const QString& label1, const QString& label2 = QString(), uint timestamp = 0);
+            ~BanListViewItem() override = default;
 
             bool operator<(const QTreeWidgetItem &item) const override;
 
-        protected:
+        private:
             QDateTime m_timestamp;
+
+            Q_DISABLE_COPY(BanListViewItem)
     };
 }
 #endif
