@@ -105,9 +105,6 @@ void LogfileReader::updateView()
     if(file.open(QIODevice::ReadOnly))
     {
         QTextStream stream(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        stream.setCodec(QTextCodec::codecForName("UTF-8"));
-#endif
         stream.setAutoDetectUnicode(true);
 
         // Set file pointer to <pos> bytes from the end
